@@ -280,6 +280,11 @@ class Highs {
     return 0;
   }
 
+  /**
+   * @brief Get the objective sense of the model
+   */
+  bool getObjectiveSense(ObjSense& sense);
+
   /**
    * @brief Get multiple columns from the model given by an interval
    */
@@ -409,7 +414,7 @@ class Highs {
   /**
    * @brief Change the objective sense of the model
    */
-  bool changeObjectiveSense(const int sense  //!< New objective sense
+  bool changeObjectiveSense(const ObjSense sense  //!< New objective sense
   );
 
   /**
