@@ -442,6 +442,10 @@ int Highs_changeRowsBoundsByMask(
     const double* upper   //!< Full length array of new upper bounds
 );
 
+/**
+ * @brief Get the objective sense
+ */
+int Highs_getObjectiveSense(void* highs, int* sense);
 /**
  * @brief Get multiple columns from the model given by an interval
  */
